- iot
a Input Output Table object - a list with elements 'inter' (= x), 'final' (= y), 'output' (= o), 'countries' (= k) and 'industries' (= i) of class 'iot'.
Alternatively these objects can be passed directly to the function, at least x, y, k and i need to be supplied.
- x
intermediate demand table supplied as a numeric matrix of dimensions GN x GN (G = no. of country, N = no. of industries).
Both rows and columns should be arranged first by country, then by industry (e.g. C1I1, C1I2, ..., C2I1, C2I2, ...) and should match (symmetry),
such that rows and columns refer to the same country-industries.
- y
final demand table supplied as a numeric matrix of dimensions GN x MN (M = no. of final demand categories recorded for each country).
The rows of y need to match the rows of x, and the columns should also be arranged first by country, then by final demand category (e.g. C1FD1, C1FD2, ..., C2FD1, C2FD2, ...) with the order of the
countries the same as in x.
- k
character. A vector of country or region names of length G, arranged in the same order as they occur in the rows and columns of x, y.
- i
character. A vector of country or region names of length N, arranged in the same order as they occur in the rows and columns of x and rows of y.
- o
numeric. A vector of final outputs for each country-industry matching the rows of x and y. If not provided it will be computed as rowSums(x) + rowSums(y).
- v
numeric. A vector of value added for each country-industry matching the columns of x. If not provided it will be computed as o - colSums(x).
- method
character. The decomposition method, either "leontief", "kww", "wwz" or "bm".
- ...
further arguments passed to leontief, kww, wwz or bm.