| kww | R Documentation |
This function performs the Koopman-Wang-Wei (2014) decomposition of a countries gross exports into 9 separate value added components.
kww(x)
x |
an object of the class 'decompr' obtained from |
A data frame where a countries gross exports is decomposed into 9 components (columns), as detailed in Figure 1 of the AER paper:
| Term | Description | ||
| DVA_FIN | Domestic VA in final goods exports. | ||
| DVA_INT | Domestic VA in intermediate exports absorbed by direct importers (used to produce a locally consumed final good). | ||
| DVA_INTrex | Domestic VA in intermediate exports reexported to third countries and absorbed there. | ||
| RDV_FIN | Domestic VA in intermediate exports that returns home via final imports. | ||
| RDV_INT | Domestic VA in intermediate exports that returns home via intermediate imports (used to produce a domestically consumed final good). | ||
| DDC | Double counted DVA in intermediate exports (arising from 2-way trade in intermediate goods). | ||
| FVA_FIN | Foreign VA in final goods exports. | ||
| FVA_INT | Foreign VA in intermediate exports. | ||
| FDC | Double counted FVA in intermediate exports (arising from 2-way trade in intermediate goods). | ||
The KWW decomposition is known to be biased. As shown by Borin and Mancini (2019), it
systematically underestimates the foreign value added in exports – and correspondingly overstates
foreign double counting – because the entire foreign content that the direct importer re-exports to
third countries is classified as 'foreign double counted', including the part (value added generated in
the importing country and re-exported onwards) that is never recorded as foreign value added in any other
flow. KWW also overlooks the bilateral dimension of trade, so it cannot correctly split domestic value
added between absorption by the direct importer and by third markets (hence indicators such as DAVAX
cannot be derived from it). Borin and Mancini (2019) correct these issues using a sink-based, world-level
perspective for the foreign content of exports; this corrected KWW decomposition is available as
bm(x, perspective = "world", approach = "sink").
Sebastian Krantz
Koopman, R., Wang, Z., & Wei, S. J. (2014). Tracing value-added and double counting in gross exports. American Economic Review, 104(2), 459-94.
Borin, A., & Mancini, M. (2019). Measuring What Matters in Global Value Chains and Value-Added Trade. World Bank Policy Research Working Paper 8804.
bm, wwz, wwz2kww, decompr-package
# Load example data
data(leather)
# Create intermediate object (class 'decompr')
decompr_object <- load_tables_vectors(leather)
# Perform the KWW decomposition
kww(decompr_object)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.