Learn R Programming

decompr (version 6.9.0)

kww: Koopman-Wang-Wei Decomposition of Gross Exports

Description

This function performs the Koopman-Wang-Wei (2014) decomposition of a countries gross exports into 9 separate value added components.

Usage

kww(x)

Value

A data frame where a countries gross exports is decomposed into 9 components (columns), as detailed in Figure 1 of the AER paper:

TermDescription
DVA_FIN
Domestic VA in final goods exports.
DVA_INTDomestic VA in intermediate exports absorbed by direct importers (used to produce a locally consumed final good).
DVA_INTrex
Domestic VA in intermediate exports reexported to third countries and absorbed there.
RDV_FINDomestic VA in intermediate exports that returns home via final imports.
RDV_INT
Domestic VA in intermediate exports that returns home via intermediate imports (used to produce a domestically consumed final good).
DDCDouble counted DVA in intermediate exports (arising from 2-way trade in intermediate goods).
FVA_FIN
Foreign VA in final goods exports.
FVA_INTForeign VA in intermediate exports.
FDC

Arguments

x

an object of the class 'decompr' obtained from load_tables_vectors.

Author

Sebastian Krantz

References

Koopman, R., Wang, Z., & Wei, S. J. (2014). Tracing value-added and double counting in gross exports. American Economic Review, 104(2), 459-94.

Borin, A., & Mancini, M. (2019). Measuring What Matters in Global Value Chains and Value-Added Trade. World Bank Policy Research Working Paper 8804.

See Also

bm, wwz, wwz2kww, decompr-package

Examples

Run this code
# Load example data
data(leather)

# Create intermediate object (class 'decompr')
decompr_object <- load_tables_vectors(leather)
 
# Perform the KWW decomposition
kww(decompr_object)

Run the code above in your browser using DataLab