powered by
This function performs the Koopman-Wang-Wei (2014) decomposition of a countries gross exports into 9 separate value added components.
kww(x)
A data frame where a countries gross exports is decomposed into 9 components (columns), as detailed in Figure 1 of the AER paper:
an object of the class 'decompr' obtained from load_tables_vectors.
load_tables_vectors
Sebastian Krantz
Koopman, R., Wang, Z., & Wei, S. J. (2014). Tracing value-added and double counting in gross exports. American Economic Review, 104(2), 459-94.
Borin, A., & Mancini, M. (2019). Measuring What Matters in Global Value Chains and Value-Added Trade. World Bank Policy Research Working Paper 8804.
bm, wwz, wwz2kww, decompr-package
bm
wwz
wwz2kww
decompr-package
# Load example data data(leather) # Create intermediate object (class 'decompr') decompr_object <- load_tables_vectors(leather) # Perform the KWW decomposition kww(decompr_object)
Run the code above in your browser using DataLab