A data frame where a countries gross exports is decomposed into 9 components (columns), as detailed in Figure 1 of the AER paper:
| Term | | | Description |
| | DVA_FIN | |
| Domestic VA in final goods exports. | | |
| DVA_INT | | | Domestic VA in intermediate exports absorbed by direct importers (used to produce a locally consumed final good). |
| | DVA_INTrex | |
| Domestic VA in intermediate exports reexported to third countries and absorbed there. | | |
| RDV_FIN | | | Domestic VA in intermediate exports that returns home via final imports. |
| | RDV_INT | |
| Domestic VA in intermediate exports that returns home via intermediate imports (used to produce a domestically consumed final good). | | |
| DDC | | | Double counted DVA in intermediate exports (arising from 2-way trade in intermediate goods). |
| |
FVA_FIN | |
| Foreign VA in final goods exports. | | |
| FVA_INT | | | Foreign VA in intermediate exports. |
| | FDC | |